import {Component, ViewChild} from '@angular/core';
import {SchedulerComponent} from './scheduler/scheduler.component';

@Component({
    selector: 'my-app',
    template: `
    <header>
      <h1><a href="..">Angular 2 demo</a></h1>
    </header>
    
    <div id="app">
    
      <div id="tools">
        <button (click)="onAddEventClick()">Add event</button>
        <button class="red" (click)="onRemoveEventClick()" [disabled]="scheduler.selectedEvent == ''">Remove event</button>
        <label class="sel-event">Selected event: <span>{{ scheduler.selectedEvent || 'None' }}</span></label>
    
        <div class="barmargin">
          <label>Barmargin:</label>
          <input min="0" max="15" type="number" [value]="barMargin" (input)="barMargin = $event.target.value-0">
        </div>
      </div>
    
      <scheduler
        #scheduler
        url="data/data.json"
        [rowHeight]=50
        [barMargin]="barMargin"
        [events]="events"
        [resources]="resources"
        [startDate]="startDate"
        [endDate]="endDate"
        [columns]="columns"
      ></scheduler>
    
    </div>
    `,
    directives: [SchedulerComponent]
})

export class AppComponent {
    @ViewChild(SchedulerComponent) scheduler: SchedulerComponent;

    title      = 'Angular 2 demo';

    //bind properties from the application to the scheduler component
    rowHeight = 50;
    selectedEvent = '';
    events = [];
    resources = [];
    barMargin = 5;
    startDate = new Date(2017, 1, 7, 8);
    endDate = new Date(2017, 1, 7, 18);
    columns = [
        { type: 'resourceInfo', text: 'Staff', field: 'name', imagePath : 'https://www.bryntum.com/dist/scheduler/examples/_shared/images/users/' },
        {
            text: 'Type',
            field: 'role',
            width: 130,
            editor: {
                type: 'combo',
                items: ['Sales', 'Developer', 'Marketing', 'Product manager'],
                editable: false,
                pickerWidth: 140
            }
        }
    ];

    onAddEventClick() {
        this.scheduler.addEvent();
    }

    onRemoveEventClick() {
        this.scheduler.removeEvent();
    }
}
