"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var http_1 = require('@angular/http');
require('rxjs/add/operator/map');
var SchedulerComponent = (function () {
    function SchedulerComponent(http, element) {
        this.http = http;
        //Available features
        this.featureInputs = [
            'columnLines', 'dependencies', 'eventDrag', 'eventContextMenu', 'eventDrag', 'eventDragCreate', 'eventEdit', 'eventFilter',
            'eventResize', 'eventTooltip', 'groupSummary', 'headerContextMenu', 'nonWorkingTime', 'scheduleTooltip',
            'summary', 'timeRanges', 'cellEdit', 'sort', 'group', 'stripe'
        ];
        //Available configs
        this.configInputs = ['autoHeight', 'viewPreset', 'startDate', 'endDate', 'events', 'resources', 'columns', 'data', 'emptyText',
            'readOnly', 'rowHeight', 'barMargin'];
        this.autoHeight = true;
        this.readOnly = false;
        this.rowHeight = 50;
        this.viewPreset = 'hourAndDay';
        this.barMargin = 5;
        // Features, only used for initialization
        this.columnLines = true;
        this.dependencies = false;
        this.eventDrag = true;
        this.eventContextMenu = true;
        this.eventDragCreator = true;
        this.cellEdit = true;
        this.eventEditor = true;
        this.eventFilter = true;
        this.eventResize = true;
        this.eventTooltip = true;
        this.scheduleTooltip = true;
        this.timeRanges = true;
        this.selectedEvent = '';
        this.onSchedulerEvents = new core_1.EventEmitter();
        // Needed later, used as target when rendering Bryntum Grid
        this.elementRef = element;
    }
    SchedulerComponent.prototype.ngOnInit = function () {
        var _this = this;
        var 
        // Features config object
        featureConfig = {}, 
        // Grid config object
        config = {
            // Render scheduler to components element
            appendTo: this.elementRef.nativeElement.firstElementChild,
            // Listeners, will relay events
            listeners: {
                catchAll: function (event) {
                    if (event.type === 'eventselectionchange') {
                        this.selectedEvent = event.selected.length ? event.selected[0].name : '';
                    }
                    this.onSchedulerEvents.emit(event);
                },
                thisObj: this
            },
            features: featureConfig
        };
        // Pass configs on to scheduler
        this.configInputs.forEach(function (configName) {
            if (configName in _this) {
                config[configName] = _this[configName];
            }
        });
        // Pass feature configs on to scheduler
        this.featureInputs.forEach(function (featureName) {
            if (featureName in _this) {
                featureConfig[featureName] = _this[featureName];
            }
        });
        this.schedulerEngine = new bryntum.scheduler.Scheduler(config);
        // load data
        this.url && this.http.get(this.url)
            .map(function (r) { return r.json(); })
            .subscribe(function (data) { return _this.loadData(data); }, function (err) { return console.error(err); });
    };
    /**
     * Consumes json in format { resources: [], events: [] }
     * @param data
     */
    SchedulerComponent.prototype.loadData = function (data) {
        var engine = this.schedulerEngine;
        engine.resources = data.resources.rows;
        engine.events = data.events.rows;
    };
    SchedulerComponent.prototype.ngOnChanges = function (changes) {
        var me = this;
        if (me.schedulerEngine) {
            // Iterate over all changes
            Object.entries(changes).forEach(function (_a) {
                var name = _a[0], currentValue = _a[1].currentValue;
                // Apply changes that match configs to grid
                if (me.configInputs.includes(name)) {
                    me.schedulerEngine[name] = currentValue;
                }
                if (me.featureInputs.includes(name)) {
                    me.schedulerEngine[name] = currentValue;
                }
            });
        }
    };
    SchedulerComponent.prototype.removeEvent = function () {
        var scheduler = this.schedulerEngine;
        scheduler.eventStore.remove(scheduler.selectedEvents);
        this.selectedEvent = '';
    };
    SchedulerComponent.prototype.addEvent = function () {
        var scheduler = this.schedulerEngine, startDate = new Date(scheduler.startDate.getTime()), endDate = new Date(startDate.getTime());
        endDate.setHours(endDate.getHours() + 1);
        scheduler.eventStore.add({
            resourceId: scheduler.resourceStore.first.id,
            startDate: startDate,
            endDate: endDate,
            name: 'New task',
            eventType: 'Meeting'
        });
    };
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], SchedulerComponent.prototype, "url", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean)
    ], SchedulerComponent.prototype, "autoHeight", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Array)
    ], SchedulerComponent.prototype, "columns", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Array)
    ], SchedulerComponent.prototype, "events", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Array)
    ], SchedulerComponent.prototype, "resources", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean)
    ], SchedulerComponent.prototype, "readOnly", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Number)
    ], SchedulerComponent.prototype, "rowHeight", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "startDate", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "endDate", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], SchedulerComponent.prototype, "viewPreset", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Number)
    ], SchedulerComponent.prototype, "barMargin", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "columnLines", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "dependencies", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventDrag", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventContextMenu", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventDragCreator", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "cellEdit", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventEditor", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventFilter", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventResize", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "eventTooltip", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "groupSummary", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "headerContextMenu", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "labels", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean)
    ], SchedulerComponent.prototype, "nonWorkingTime", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "scheduleTooltip", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "summaryToolbar", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "timeRanges", void 0);
    __decorate([
        core_1.Output(), 
        __metadata('design:type', String)
    ], SchedulerComponent.prototype, "selectedEvent", void 0);
    __decorate([
        core_1.Output(), 
        __metadata('design:type', Object)
    ], SchedulerComponent.prototype, "onSchedulerEvents", void 0);
    SchedulerComponent = __decorate([
        core_1.Component({
            selector: 'scheduler',
            template: '<div></div>',
            providers: [http_1.HTTP_PROVIDERS]
        }), 
        __metadata('design:paramtypes', [http_1.Http, core_1.ElementRef])
    ], SchedulerComponent);
    return SchedulerComponent;
}());
exports.SchedulerComponent = SchedulerComponent;
//# sourceMappingURL=scheduler.component.js.map